@@ -413,17 +413,6 @@ Grund:
         <translation>Link in neuem Reiter öffnen</translation>
     </message>
 </context>
-<context>
-    <name>FilterNameDialogClass</name>
-    <message>
-        <source>Add Filter Name</source>
-        <translation>Filternamen hinzufügen</translation>
-    </message>
-    <message>
-        <source>Filter Name:</source>
-        <translation>Filtername:</translation>
-    </message>
-</context>
 <context>
     <name>FindWidget</name>
     <message>
@@ -510,10 +499,37 @@ Grund:
     </message>
 </context>
 <context>
-    <name>HelpEngineWrapper</name>
+    <name>HelpDocSettingsWidget</name>
     <message>
-        <source>Unfiltered</source>
-        <translation>Ungefiltert</translation>
+        <source>Form</source>
+        <translation>Form</translation>
+    </message>
+    <message>
+        <source>Registered Documentation</source>
+        <translation>Registrierte Dokumentationen</translation>
+    </message>
+    <message>
+        <source>&lt;Filter&gt;</source>
+        <translation>&lt;Filter&gt;</translation>
+    </message>
+    <message>
+        <source>Add...</source>
+        <translation>Hinzufügen...</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation>Entfernen</translation>
+    </message>
+</context>
+<context>
+    <name>HelpDocSettingsWidgetPrivate</name>
+    <message>
+        <source>Add Documentation</source>
+        <translation>Dokumentation hinzufügen</translation>
+    </message>
+    <message>
+        <source>Qt Compressed Help Files (*.qch)</source>
+        <translation>Komprimierte Qt-Hilfedateien (*.qch)</translation>
     </message>
 </context>
 <context>
@@ -688,6 +704,10 @@ Grund:
         <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;p&gt;Browser: %3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %4 The Qt Company Ltd.&lt;/p&gt;</source>
         <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;p&gt;Browser: %3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %4 The Qt Company Ltd.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Unfiltered</source>
+        <translation>Ungefiltert</translation>
+    </message>
     <message>
         <source>Could not register file &apos;%1&apos;: %2</source>
         <translation>Die Datei &apos;%1&apos; konnte nicht registriert werden: %2</translation>
@@ -810,38 +830,6 @@ Grund:
 </context>
 <context>
     <name>PreferencesDialog</name>
-    <message>
-        <source>Add Documentation</source>
-        <translation>Dokumentation hinzufügen</translation>
-    </message>
-    <message>
-        <source>Qt Compressed Help Files (*.qch)</source>
-        <translation>Komprimierte Hilfedateien (*.qch)</translation>
-    </message>
-    <message>
-        <source>The specified file is not a valid Qt Help File!</source>
-        <translation>Die angegebene Datei ist keine Qt-Hilfedatei.</translation>
-    </message>
-    <message>
-        <source>The namespace %1 is already registered!</source>
-        <translation>Der Namespace %1 ist bereits registriert.</translation>
-    </message>
-    <message>
-        <source>Remove Documentation</source>
-        <translation>Dokumentation entfernen</translation>
-    </message>
-    <message>
-        <source>Some documents currently opened in Assistant reference the documentation you are attempting to remove. Removing the documentation will close those documents.</source>
-        <translation>Einige der derzeit geöffneten Dokumente stammen aus der Dokumentation, die Sie gerade zu löschen versuchen. Sie werden beim Löschen geschlossen.</translation>
-    </message>
-    <message>
-        <source>Cancel</source>
-        <translation>Abbrechen</translation>
-    </message>
-    <message>
-        <source>OK</source>
-        <translation>OK</translation>
-    </message>
     <message>
         <source>Use custom settings</source>
         <translation>Benutzerdefinierte Einstellungen verwenden</translation>
@@ -873,38 +861,10 @@ Grund:
         <source>Filters</source>
         <translation>Filter</translation>
     </message>
-    <message>
-        <source>Filter:</source>
-        <translation>Filter:</translation>
-    </message>
-    <message>
-        <source>Attributes:</source>
-        <translation>Attribute:</translation>
-    </message>
-    <message>
-        <source>1</source>
-        <translation>1</translation>
-    </message>
-    <message>
-        <source>Add</source>
-        <translation>Hinzufügen</translation>
-    </message>
-    <message>
-        <source>Remove</source>
-        <translation>Entfernen</translation>
-    </message>
     <message>
         <source>Documentation</source>
         <translation>Dokumentation</translation>
     </message>
-    <message>
-        <source>Registered Documentation:</source>
-        <translation>Registrierte Dokumentation:</translation>
-    </message>
-    <message>
-        <source>Add...</source>
-        <translation>Hinzufügen ...</translation>
-    </message>
     <message>
         <source>Options</source>
         <translation>Einstellungen</translation>
@@ -949,10 +909,6 @@ Grund:
         <source>Show tabs for each individual page</source>
         <translation>Reiter für jede einzelne Seite anzeigen</translation>
     </message>
-    <message>
-        <source>&lt;Filter&gt;</source>
-        <translation>&lt;Filter&gt;</translation>
-    </message>
 </context>
 <context>
     <name>RemoteControl</name>
